/*
 * YACA : Yet Another Contact Application 
 * by PhilFlash - http://philflash.inway.fr
 *
 */

import mx.controls.Button;
import mx.controls.DataGrid;
import mx.controls.gridclasses.DataGridColumn;
import mx.controls.Alert;

import MyLocale;

class ListContactForm extends mx.screens.Form {

	public var editButton:Button = null;
	public var newButton:Button = null;
	public var removeButton:Button = null;
	public var contact_dg:DataGrid = null;
	
	private var revealFirst:Boolean = true;
	
	// Constructor
	public function ListContactForm() {}
	

	public function init():Void {
		super.init();
		addEventListener("load", onLoad);
		addEventListener("reveal", onReveal);
		addEventListener("allTransitionsInDone", this);	
	}
	
	public function onLoad( obj:Object ):Void {
		setVisible(false);
		
		editButton.addEventListener("click", function(evt:Object) { evt.target._parent.editAction(evt); } );
		newButton.addEventListener("click", function(evt:Object) { evt.target._parent.newAction(evt); } );
		removeButton.addEventListener("click", function(evt:Object) { evt.target._parent.removeAction(evt); } )		
		
		// -- init DataGrid --
		
		contact_dg.columnNames = ["first", "last", "email"];
		
		var col:mx.controls.gridclasses.DataGridColumn;

		col = contact_dg.getColumnAt(0);
		col.width = 100;

		col = contact_dg.getColumnAt(1);
		col.width = 100;


		contact_dg.setStyle("alternatingRowColors", Array(0xFFFFFF, 0xF7F7F7));
		
		// -- --
		(rootForm).contact_ds.addEventListener("afterLoaded", this);


	}
	
	public function afterLoaded(eventObj:Object):Void {
		// Forces the calculation of the width of the last column
		contact_dg.size();
		
		// Change the label for header 
		var col:mx.controls.gridclasses.DataGridColumn;

		col = contact_dg.getColumnAt(0);
		col.headerText = MyLocale.getString("IDS_HEADER_FIRST");

		col = contact_dg.getColumnAt(1);
		col.headerText = MyLocale.getString("IDS_HEADER_LAST");

		col = contact_dg.getColumnAt(2);
		col.headerText = MyLocale.getString("IDS_HEADER_EMAIL");
	}
	
	// ----- Reveal -----
	public function onReveal(eventObj:Object):Void {	
		var transition:Object = null;	
		
		if (revealFirst) {
			revealFirst = false;
			
			transition = new Object();
			transition.type = mx.transitions.Fly;
			transition.direction = 0;
			transition.duration = 2;
			transition.easing = mx.transitions.easing.Strong.easeOut;
			transition.startPoint = 6;
			transition.param2 = "";
			
			mx.transitions.TransitionManager.start( this, transition );	
		} 
	}
	
	public function allTransitionsInDone():Void {
		refreshButtons();	
	}
	
	// ----- Action -----
	private function refreshButtons():Void {
		var len:Number = (rootForm).contact_ds.getLength();
		if (len == 0) {
			editButton.enabled = false;
			removeButton.enabled = false;
		} else {
			editButton.enabled = true;
			removeButton.enabled = true;			
		}
	
	}
	
	// ----- Edit Contact -----
	public function editAction(eventObj:Object):Void {
	
		// force update view
		contact_dg.dispatchEvent({ type:"change"});
		
	  	(rootForm).editcontact.isNew = false;
		
		setVisible(false);
		// Show Screen editcontact
        (rootForm).editcontact.setVisible(true);
	}

	// ----- Add Contact -----
	public function newAction(eventObj:Object):Void {
	
		// add a new Item
		var newContact:Object = {first:"", last:"", email:"", work:"", home:""};
	  	(rootForm).contact_ds.addItem(newContact);
  	
		// force update view
		contact_dg.dispatchEvent({ type:"change"});
	  	
	  	(rootForm).editcontact.isNew = true;

		refreshButtons();	  	
		
		setVisible(false);
		// Show Screen editcontact
       	(rootForm).editcontact.setVisible(true);
	}
	
	// ----- Remove Contact -----
	public function removeAction(eventObj:Object):Void {
		var item = (rootForm).contact_ds.currentItem;
		// -- format Message --
		var message:String = MyLocale.getString("IDS_REMOVE_CONTACT_MESSAGE"); // "Remove '%1 %2' ? Are you sure ?";
		var fmessage = message;
		fmessage = replace(fmessage, "%1", item.first);
		fmessage = replace(fmessage, "%2", item.last);
		
		var title = MyLocale.getString("IDS_REMOVE_CONTACT_TITLE");
		
		Alert.cancelLabel = MyLocale.getString("IDS_LABEL_CANCEL");
		Alert.okLabel = MyLocale.getString("IDS_LABEL_OK");
		// 
		var confirm:Alert = Alert.show(fmessage, title, Alert.OK | Alert.CANCEL, this, this.confirmDeleteHandler, null, Alert.CANCEL);
		confirm.owner = this;
		//setLocationRelativeTo(confirm, eventObj.target);	
		setLocationRelativeTo(confirm, null);	
	}	
	
	public function confirmDeleteHandler(eventObj:Object):Void {
		var detail = eventObj.detail;
		var target = eventObj.target;
		if (detail == Alert.OK || detail == Alert.YES) {
			target.owner.rootForm.contact_ds.removeItem();
			target.owner.refreshButtons();
		}
	
	}

	
	// -----  -----
	public function refreshLangForComponents():Void {
		editButton.label = MyLocale.getString("IDS_EDIT");
		newButton.label = MyLocale.getString("IDS_NEW");
		removeButton.label = MyLocale.getString("IDS_REMOVE");
	}
	
	// -----  -----	
	// replaces the from string to to string and returns the modified 
	public function replace(str:String,from:String,to:String):String {
		var arrStr:Array = str.split(from);
		var repStr:String = arrStr.join(to);
		return repStr;
	}

	// -----  -----
	function setLocationRelativeTo(mc:MovieClip, owner:Object) {
		var x0:Number = 0;
		var y0:Number = 0;
		if (owner != undefined && owner instanceof MovieClip) {
			x0 = owner._x+(owner._width/2);
			y0 = owner._y+(owner._height/2);	
			var x:Number = x0 - mc._width/2;
			var y:Number = y0 - mc._height/2;
			if (x < 0) {
				x = 0;
			}
			if (y < 0) {
				y = 0;
			}
			if (x + mc._width > Stage.width) {
				x = Stage.width - mc._width;
			}
			if (y + mc._height > Stage.height) {
				y = Stage.height - mc.height;
			}

			mc.move(x,y);		
		} else {
			mc.move((Stage.width-mc._width)/2, (Stage.height-mc._height)/2);	
		}
	}
}
